@@ -257,7 +257,7 @@ class Simulation:
             self.data_3d = Plot3DCollection(self.data_3d.keys(), self.data_3d.values())
             self.smoke_3d = Smoke3DCollection(self.smoke_3d.values())
             self.isosurfaces = IsosurfaceCollection(self.isosurfaces.values())
-            # If no particles are simulates, initialize empty data container for consistency
+            # If no particles are simulated, initialize empty data container for consistency
             if len(self.particles) == 0:
                 self.particles = ParticleCollection((), ())
             else:
@@ -505,7 +505,7 @@ class Simulation:
 
         slice_index = int(line.split('!')[1].strip().split()[0])
 
-        slice_id = "".join(line.split('%')[1].split('&')).strip() if '%' in line else ""
+        slice_id = line.split('%')[1].split('&')[0].strip() if '%' in line else ""
 
         mesh_index = int(line.split('&')[0].strip().split()[1]) - 1
         mesh = self.meshes[mesh_index]
